# [Zope-tests] OK : Zope-2.11 Python-2.4.6 : Linux

Zope Tests zope-tests at epy.co.at
Wed Feb 2 01:09:00 EST 2011

- Previous message: [Zope-tests] OK : Zope-2.10 Python-2.4.6 : Linux
- Next message: [Zope-tests] OK : Zope-2.12 Python-2.6.5 : Linux
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    Zope Tests : OK
    Zope-2.11 Python-2.4.6 : Linux (x86_64)

    Running /usr/local/python2.4/bin/python test.py -q --all
    Running unit tests:
    The following test left new threads behind:
    testABOR (zope.server.ftp.tests.test_ftpserver.Tests)
    New thread(s): [<_DummyThread(Dummy-37, started daemon)>, <_DummyThread(Dummy-36, started daemon)>, <_DummyThread(Dummy-38, started daemon)>]
      Ran 5904 tests with 0 failures and 0 errors in 1 minutes 59.577 seconds.
    Running OFS.tests.testCopySupportEvents.EventLayer tests:
      Set up OFS.tests.testCopySupportEvents.EventLayer in 0.213 seconds.
      Ran 14 tests with 0 failures and 0 errors in 0.095 seconds.
    Running OFS.tests.testCopySupportHooks.HookLayer tests:
      Tear down OFS.tests.testCopySupportEvents.EventLayer in 0.002 seconds.
      Set up OFS.tests.testCopySupportHooks.HookLayer in 0.211 seconds.
      Ran 14 tests with 0 failures and 0 errors in 0.093 seconds.
    Running Testing.ZopeTestCase.layer.ZopeLite tests:
      Tear down OFS.tests.testCopySupportHooks.HookLayer in 0.002 seconds.
      Set up Testing.ZopeTestCase.layer.ZopeLite in 0.000 seconds.
      Ran 673 tests with 0 failures and 0 errors in 9.580 seconds.
    Running Testing.ZopeTestCase.testShoppingCart.ShoppingCartLayer tests:
      Set up Testing.ZopeTestCase.testShoppingCart.ShoppingCartLayer in 0.076 seconds.
      Ran 16 tests with 0 failures and 0 errors in 0.157 seconds.
    Running Testing.ZopeTestCase.testZODBCompat.ZODBCompatLayer tests:
      Tear down Testing.ZopeTestCase.testShoppingCart.ShoppingCartLayer in 0.001 seconds.
      Set up Testing.ZopeTestCase.testZODBCompat.ZODBCompatLayer in 0.001 seconds.
      Ran 18 tests with 0 failures and 0 errors in 0.037 seconds.
    Running Testing.ZopeTestCase.zopedoctest.testLayerExtraction.TestLayer tests:
      Tear down Testing.ZopeTestCase.testZODBCompat.ZODBCompatLayer in 0.001 seconds.
      Set up Testing.ZopeTestCase.zopedoctest.testLayerExtraction.TestLayer in 0.001 seconds.
      Ran 2 tests with 0 failures and 0 errors in 0.007 seconds.
    Running zope.formlib.tests.FormlibLayer tests:
      Tear down Testing.ZopeTestCase.zopedoctest.testLayerExtraction.TestLayer in 0.001 seconds.
      Tear down Testing.ZopeTestCase.layer.ZopeLite in 0.000 seconds.
      Set up zope.formlib.tests.FormlibLayer in 0.612 seconds.
      Ran 5 tests with 0 failures and 0 errors in 0.006 seconds.
    Running zope.testbrowser.tests.TestBrowserLayer tests:
      Tear down zope.formlib.tests.FormlibLayer in 0.002 seconds.
      Set up zope.testbrowser.tests.TestBrowserLayer in 0.492 seconds.
      Ran 112 tests with 0 failures and 0 errors in 1.030 seconds.
    Running zope.traversing.tests.layer.TraversingLayer tests:
      Tear down zope.testbrowser.tests.TestBrowserLayer in 0.002 seconds.
      Set up zope.traversing.tests.layer.TraversingLayer in 0.449 seconds.
      Ran 7 tests with 0 failures and 0 errors in 0.145 seconds.
    Tearing down left over layers:
      Tear down zope.traversing.tests.layer.TraversingLayer in 0.002 seconds.
    Total: 6765 tests, 0 failures, 0 errors in 2 minutes 15.939 seconds.

    OK

- Previous message: [Zope-tests] OK : Zope-2.10 Python-2.4.6 : Linux
- Next message: [Zope-tests] OK : Zope-2.12 Python-2.6.5 : Linux
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list